@@ -20,6 +20,7 @@ use AsyncAws\Sns\Exception\InvalidBatchEntryIdException;
 use AsyncAws\Sns\Exception\InvalidParameterException;
 use AsyncAws\Sns\Exception\InvalidParameterValueException;
 use AsyncAws\Sns\Exception\InvalidSecurityException;
+use AsyncAws\Sns\Exception\InvalidStateException;
 use AsyncAws\Sns\Exception\KMSAccessDeniedException;
 use AsyncAws\Sns\Exception\KMSDisabledException;
 use AsyncAws\Sns\Exception\KMSInvalidStateException;
@@ -28,6 +29,7 @@ use AsyncAws\Sns\Exception\KMSOptInRequiredException;
 use AsyncAws\Sns\Exception\KMSThrottlingException;
 use AsyncAws\Sns\Exception\NotFoundException;
 use AsyncAws\Sns\Exception\PlatformApplicationDisabledException;
+use AsyncAws\Sns\Exception\ReplayLimitExceededException;
 use AsyncAws\Sns\Exception\StaleTagException;
 use AsyncAws\Sns\Exception\SubscriptionLimitExceededException;
 use AsyncAws\Sns\Exception\TagLimitExceededException;
@@ -78,8 +80,8 @@ class SnsClient extends AbstractApi
      * @param array{
      *   PlatformApplicationArn: string,
      *   Token: string,
-     *   CustomUserData?: string,
-     *   Attributes?: array<string, string>,
+     *   CustomUserData?: null|string,
+     *   Attributes?: null|array<string, string>,
      *   '@region'?: string|null,
      * }|CreatePlatformEndpointInput $input
      *
@@ -114,9 +116,9 @@ class SnsClient extends AbstractApi
      *
      * @param array{
      *   Name: string,
-     *   Attributes?: array<string, string>,
-     *   Tags?: array<Tag|array>,
-     *   DataProtectionPolicy?: string,
+     *   Attributes?: null|array<string, string>,
+     *   Tags?: null|array<Tag|array>,
+     *   DataProtectionPolicy?: null|string,
      *   '@region'?: string|null,
      * }|CreateTopicInput $input
      *
@@ -195,6 +197,7 @@ class SnsClient extends AbstractApi
      * }|DeleteTopicInput $input
      *
      * @throws InvalidParameterException
+     * @throws InvalidStateException
      * @throws InternalErrorException
      * @throws AuthorizationErrorException
      * @throws NotFoundException
@@ -207,6 +210,7 @@ class SnsClient extends AbstractApi
         $input = DeleteTopicInput::create($input);
         $response = $this->getResponse($input->request(), new RequestContext(['operation' => 'DeleteTopic', 'region' => $input->getRegion(), 'exceptionMapping' => [
             'InvalidParameter' => InvalidParameterException::class,
+            'InvalidState' => InvalidStateException::class,
             'InternalError' => InternalErrorException::class,
             'AuthorizationError' => AuthorizationErrorException::class,
             'NotFound' => NotFoundException::class,
@@ -230,7 +234,7 @@ class SnsClient extends AbstractApi
      *
      * @param array{
      *   TopicArn: string,
-     *   NextToken?: string,
+     *   NextToken?: null|string,
      *   '@region'?: string|null,
      * }|ListSubscriptionsByTopicInput $input
      *
@@ -263,7 +267,7 @@ class SnsClient extends AbstractApi
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sns-2010-03-31.html#listtopics
      *
      * @param array{
-     *   NextToken?: string,
+     *   NextToken?: null|string,
      *   '@region'?: string|null,
      * }|ListTopicsInput $input
      *
@@ -307,15 +311,15 @@ class SnsClient extends AbstractApi
      * @see https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-sns-2010-03-31.html#publish
      *
      * @param array{
-     *   TopicArn?: string,
-     *   TargetArn?: string,
-     *   PhoneNumber?: string,
+     *   TopicArn?: null|string,
+     *   TargetArn?: null|string,
+     *   PhoneNumber?: null|string,
      *   Message: string,
-     *   Subject?: string,
-     *   MessageStructure?: string,
-     *   MessageAttributes?: array<string, MessageAttributeValue|array>,
-     *   MessageDeduplicationId?: string,
-     *   MessageGroupId?: string,
+     *   Subject?: null|string,
+     *   MessageStructure?: null|string,
+     *   MessageAttributes?: null|array<string, MessageAttributeValue|array>,
+     *   MessageDeduplicationId?: null|string,
+     *   MessageGroupId?: null|string,
      *   '@region'?: string|null,
      * }|PublishInput $input
      *
@@ -449,7 +453,7 @@ class SnsClient extends AbstractApi
      * to confirm the subscription.
      *
      * You call the `ConfirmSubscription` action with the token from the subscription response. Confirmation tokens are
-     * valid for three days.
+     * valid for two days.
      *
      * This action is throttled at 100 transactions per second (TPS).
      *
@@ -459,14 +463,15 @@ class SnsClient extends AbstractApi
      * @param array{
      *   TopicArn: string,
      *   Protocol: string,
-     *   Endpoint?: string,
-     *   Attributes?: array<string, string>,
-     *   ReturnSubscriptionArn?: bool,
+     *   Endpoint?: null|string,
+     *   Attributes?: null|array<string, string>,
+     *   ReturnSubscriptionArn?: null|bool,
      *   '@region'?: string|null,
      * }|SubscribeInput $input
      *
      * @throws SubscriptionLimitExceededException
      * @throws FilterPolicyLimitExceededException
+     * @throws ReplayLimitExceededException
      * @throws InvalidParameterException
      * @throws InternalErrorException
      * @throws NotFoundException
@@ -479,6 +484,7 @@ class SnsClient extends AbstractApi
         $response = $this->getResponse($input->request(), new RequestContext(['operation' => 'Subscribe', 'region' => $input->getRegion(), 'exceptionMapping' => [
             'SubscriptionLimitExceeded' => SubscriptionLimitExceededException::class,
             'FilterPolicyLimitExceeded' => FilterPolicyLimitExceededException::class,
+            'ReplayLimitExceeded' => ReplayLimitExceededException::class,
             'InvalidParameter' => InvalidParameterException::class,
             'InternalError' => InternalErrorException::class,
             'NotFound' => NotFoundException::class,
@@ -549,6 +555,13 @@ class SnsClient extends AbstractApi
                     'signService' => 'sns',
                     'signVersions' => ['v4'],
                 ];
+            case 'fips-ca-west-1':
+                return [
+                    'endpoint' => 'https://sns-fips.ca-west-1.amazonaws.com',
+                    'signRegion' => 'ca-west-1',
+                    'signService' => 'sns',
+                    'signVersions' => ['v4'],
+                ];
             case 'fips-us-east-1':
                 return [
                     'endpoint' => 'https://sns-fips.us-east-1.amazonaws.com',
